Crate limqch

Crate limqch 

Channel based on LimQ.

Structs

Ctrl
Proxy object to allow Sender and Receiver instances to access the internal queue’s Controller.
Receiver
Channel receiver end-point.
RecvFuture
A Future that will will resolve when there’s data that can be returned from the channel, of it the internal queue is empty but all the Sender end-points have been dropped.
Sender
Channel transmitter end-point.

Enums

Error
Errors that Sender and Receiver methods can return.
Overflow
Control how forced push handles overflow.

Traits

Controller
Implemented for objects that are used to monitor/control queue limits.

Functions

channel
Create a channel pair, with an optional internal queue limit.