Channel based on LimQ.
Structs
- Ctrl
- Proxy object to allow
SenderandReceiverinstances to access the internal queue’sController. - Receiver
- Channel receiver end-point.
- Recv
Future - A
Futurethat will will resolve when there’s data that can be returned from the channel, of it the internal queue is empty but all theSenderend-points have been dropped. - Sender
- Channel transmitter end-point.
Enums
- Error
- Errors that
SenderandReceivermethods can return. - Overflow
- Control how forced push handles overflow.
Traits
- Controller
- Implemented for objects that are used to monitor/control queue limits.
Functions
- channel
- Create a channel pair, with an optional internal queue limit.